<?php

namespace SGalinski\SgJobs\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\DomainObject\AbstractEntity;
use TYPO3\CMS\Extbase\Persistence\ObjectStorage;

/**
 * The JobApplication model
 */
class JobApplication extends AbstractEntity {
	/**
	 * An internal id for external purposes
	 *
	 * @var string $jobId
	 */
	protected $jobId = '';

	/**
	 * @var string $gender
	 * @validate NotEmpty
	 */
	protected $gender = 0;

	/**
	 * @var string $firstName
	 * @validate NotEmpty
	 */
	protected $firstName = '';

	/**
	 * @var string $lastName
	 * @validate NotEmpty
	 */
	protected $lastName = '';

	/**
	 * @var string $street
	 * @validate NotEmpty
	 */
	protected $street = '';

	/**
	 * @var string $city
	 * @validate NotEmpty
	 */
	protected $city = '';

	/**
	 * @var string $zip
	 * @validate NotEmpty
	 */
	protected $zip = '';

	/**
	 * @var string $country
	 * @validate NotEmpty
	 */
	protected $country = '';

	/**
	 * @var string $nationality
	 * @validate NotEmpty
	 */
	protected $nationality = '';

	/**
	 * @var string $education
	 * @validate NotEmpty
	 */
	protected $education = '';

	/**
	 * @var string $birthDate
	 * @validate NotEmpty
	 */
	protected $birthDate = '';

	/**
	 * @var string $phone
	 * @validate NotEmpty
	 */
	protected $phone = '';

	/**
	 * @var string $mobile
	 */
	protected $mobile = '';

	/**
	 * @var string $email
	 * @validate NotEmpty, EmailAddress
	 */
	protected $email = '';

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\FileReference $coverLetter
	 *
	 */
	protected $coverLetter;

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\FileReference $cv
	 *
	 */
	protected $cv;

	/**
	 * @var \SGalinski\SgJobs\Domain\Model\FileReference $certificate
	 *
	 */
	protected $certificate;

	/**
	 * @var string
	 */
	protected $message = '';

	/**
	 * @return string
	 */
	public function getJobId() {
		return $this->jobId;
	}

	/**
	 * @param string $jobId
	 */
	public function setJobId($jobId) {
		$this->jobId = $jobId;
	}

	/**
	 * @return string
	 */
	public function getGender() {
		return $this->gender;
	}

	/**
	 * @param string $gender
	 */
	public function setGender(string $gender) {
		$this->gender = $gender;
	}

	/**
	 * @return string
	 */
	public function getFirstName() {
		return $this->firstName;
	}

	/**
	 * @param string $firstName
	 */
	public function setFirstName(string $firstName) {
		$this->firstName = $firstName;
	}

	/**
	 * @return string
	 */
	public function getLastName() {
		return $this->lastName;
	}

	/**
	 * @param string $lastName
	 */
	public function setLastName(string $lastName) {
		$this->lastName = $lastName;
	}

	/**
	 * @return string
	 */
	public function getStreet() {
		return $this->street;
	}

	/**
	 * @param string $street
	 */
	public function setStreet(string $street) {
		$this->street = $street;
	}

	/**
	 * @return string
	 */
	public function getCity() {
		return $this->city;
	}

	/**
	 * @param string $city
	 */
	public function setCity(string $city) {
		$this->city = $city;
	}

	/**
	 * @return string
	 */
	public function getZip() {
		return $this->zip;
	}

	/**
	 * @param string $zip
	 */
	public function setZip(string $zip) {
		$this->zip = $zip;
	}

	/**
	 * @return string
	 */
	public function getCountry() {
		return $this->country;
	}

	/**
	 * @param string $country
	 */
	public function setCountry(string $country) {
		$this->country = $country;
	}

	/**
	 * @return string
	 */
	public function getNationality() {
		return $this->nationality;
	}

	/**
	 * @param string $nationality
	 */
	public function setNationality(string $nationality) {
		$this->nationality = $nationality;
	}

	/**
	 * @return string
	 */
	public function getEducation() {
		return $this->education;
	}

	/**
	 * @param string $education
	 */
	public function setEducation(string $education) {
		$this->education = $education;
	}

	/**
	 * @return int
	 */
	public function getBirthDate() {
		return $this->birthDate;
	}

	/**
	 * @param int $birthDate
	 */
	public function setBirthDate($birthDate) {
		$this->birthDate = (int) $birthDate;
	}

	/**
	 * @return string
	 */
	public function getPhone() {
		return $this->phone;
	}

	/**
	 * @param string $phone
	 */
	public function setPhone(string $phone) {
		$this->phone = $phone;
	}

	/**
	 * @return string
	 */
	public function getMobile() {
		return $this->mobile;
	}

	/**
	 * @param string $mobile
	 */
	public function setMobile(string $mobile) {
		$this->mobile = $mobile;
	}

	/**
	 * @return string
	 */
	public function getEmail() {
		return $this->email;
	}

	/**
	 * @param string $email
	 */
	public function setEmail(string $email) {
		$this->email = $email;
	}

	/**
	 * @return \SGalinski\SgJobs\Domain\Model\FileReference
	 */
	public function getCoverLetter() {
		return $this->coverLetter;
	}

	/**
	 * @param \SGalinski\SgJobs\Domain\Model\FileReference $coverLetter
	 */
	public function setCoverLetter(\SGalinski\SgJobs\Domain\Model\FileReference $coverLetter = NULL) {
		$this->coverLetter = $coverLetter;
	}

	/**
	 * @return \SGalinski\SgJobs\Domain\Model\FileReference
	 */
	public function getCv() {
		return $this->cv;
	}

	/**
	 * @param \SGalinski\SgJobs\Domain\Model\FileReference $cv
	 */
	public function setCV(\SGalinski\SgJobs\Domain\Model\FileReference $cv = NULL) {
		$this->cv = $cv;
	}

	/**
	 * @return \SGalinski\SgJobs\Domain\Model\FileReference
	 */
	public function getCertificate() {
		return $this->certificate;
	}

	/**
	 * @param \SGalinski\SgJobs\Domain\Model\FileReference $certificate
	 */
	public function setCertificate(\SGalinski\SgJobs\Domain\Model\FileReference $certificate = NULL) {
		$this->certificate = $certificate;
	}

	/**
	 * @return string
	 */
	public function getMessage() {
		return $this->message;
	}

	/**
	 * @param string $message
	 */
	public function setMessage(string $message) {
		$this->message = $message;
	}
}
